@@ -109,7 +109,8 @@
 #'   negative values. If the entire axis is already negative, this will be set
 #'   to \code{TRUE} for you.
 #' @param exact \code{logical}. Set this to \code{TRUE} if you want axis tick
-#'   marks and numeric tick labels placed at the interval boundaries.
+#'   marks and numeric tick labels placed at the interval boundaries. If
+#'   \code{TRUE}, this overrides \code{tick_at} and \code{tick_labels}.
 #' @param round \code{integer}. Number of decimal places to which exact axis
 #'   labels should be rounded (using \code{\link[base]{round}}). If no value is
 #'   specified, the exact values will be used. Trailing zeros are always
@@ -117,13 +118,15 @@
 #'   labels with trailing zeros.
 #' @param tick_at A \code{numeric} vector specifying custom points at which tick
 #'   marks are to be drawn on the axis. If specified, this is passed directly to
-#'   \code{\link[graphics]{axis}}. The default is to compute tick mark locations
-#'   automatically (see \code{\link[graphics]{axTicks}}).
+#'   \code{\link[graphics]{axis}}. If \code{phylo} is \code{TRUE}, these values
+#'   are converted as necessary for the phylogenetic axis limits. If this is set
+#'   to \code{NULL} (the default) tick mark locations are computed automatically
+#'   (see \code{\link[graphics]{axTicks}}).
 #' @param tick_labels Either a) a \code{logical} value specifying whether
 #'   (numerical) annotations should be made at the tick marks specified by
-#'   \code{at}, or b) a custom \code{character} or \code{expression} vector of
-#'   labels to be placed at the tick marks. If \code{at} is specified, this
-#'   argument is passed directly to \code{\link[graphics]{axis}}.
+#'   \code{tick_at}, or b) a custom \code{character} or \code{expression} vector
+#'   of labels to be placed at the tick marks. If \code{tick_at} is specified,
+#'   this argument is passed directly to \code{\link[graphics]{axis}}.
 #' @param phylo \code{logical}. Is the base plot a phylogeny generated by
 #'   \code{\link[ape]{plot.phylo}}, \code{\link[phytools]{plotTree}},
 #'   \code{\link[phytools]{plotSimmap}}, etc?
@@ -569,17 +572,28 @@ axis_geo <- function(
 
   # after placing the scales, add an axis with ticks and labels
   # use interval boundaries if `exact` is TRUE
-  if (exact == TRUE && is.null(tick_at)) {
+  if (exact == TRUE) {
     # Use the interval breaks from the outer-most scale
     tick_at <- unique(c(scale_intervals$min_ma, scale_intervals$max_ma))
+    if (phylo) {
+      tick_at <- (tick_at - phylo_alpha) / phylo_beta
+    }
     if (is.numeric(round)) {
       tick_labels <- round(tick_at, round)
     } else {
       tick_labels <- as.character(tick_at) # removes trailing zeros
     }
-  } else if (phylo) {
-    tick_labels <- pretty(phylo_scale)
-    tick_at <- phylo_beta * tick_labels + phylo_alpha
+  }
+  if (phylo) {
+    if (is.null(tick_at)) {
+      tick_at <- pretty(phylo_scale)
+    }
+    if (is.logical(tick_labels) && tick_labels) {
+      tick_labels <- as.character(tick_at)
+    }
+    # Convert to ape scale
+    tick_at <- phylo_beta * tick_at + phylo_alpha
+
     # Filter to only ticks within limits
     if (side %in% c(1, 3)) {
       tick_inc <- which(tick_at <= scale_lims[2] & tick_at >= scale_lims[1])
@@ -589,6 +603,8 @@ axis_geo <- function(
     tick_at <- tick_at[tick_inc]
     tick_labels <- tick_labels[tick_inc]
   }
+
+  # Add axis with ticks
   if (side == 1) {
     axis(side = side, pos = clip_lims[3], at = tick_at, labels = tick_labels,
          lty = lty[[scale]], ...)
